@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -7,7 +7,7 @@
 #include "ldapclientsearchconfigreadconfigjobtest.h"
 #include "ldapclientsearchconfigreadconfigjob.h"
 #include <QTest>
-QTEST_MAIN(LdapClientSearchConfigReadConfigJobTest)
+QTEST_GUILESS_MAIN(LdapClientSearchConfigReadConfigJobTest)
 LdapClientSearchConfigReadConfigJobTest::LdapClientSearchConfigReadConfigJobTest(QObject *parent)
     : QObject(parent)
 {
